@@ -1,4 +1,4 @@
-from typing import ByteString, Dict, Iterable, Mapping
+from typing import ByteString, Dict, Iterable, Mapping, Text
 
 
 def decode_dict(data: Dict[bytes, bytes]) -> Dict[str, str]:
@@ -13,9 +13,9 @@ def decode_dict(data: Dict[bytes, bytes]) -> Dict[str, str]:
             ret[key] = decode_dict(value)
         elif isinstance(value, ByteString):
             ret[key] = value.decode()
-        elif isinstance(value, Iterable):
+        elif isinstance(value, Iterable) and not isinstance(value, Text):
             ret[key] = value.__new__(
-                (x.decode() if isinstance(x, bytes) else x for x in value)
+                x.decode() if isinstance(x, ByteString) else x for x in value
             )
         else:
             ret[key] = value
